function plotRCSConductingCylinder()
% Generate the far-field radar cross-section of a conducting cylinder
% under the plane wave excitation. This is the duplication of Fig. 11-13
% of [Balanis1989].
%
    
    radius     = [0.05;0.1;0.2;0.4;0.6]; %wavelength
    background = DielectricMaterial(1, 0);
    frequency  = 1.0;
    wavelength = getWavelength(background, frequency);

    phi        = linspace(0,pi,51)';
    sensor_distance = 10000; % wavelength
    E_z        = zeros(length(phi),length(radius));
    for i = 1:length(phi)
        for j = 1:length(radius)
            sensor_location = [sensor_distance*cos(phi(i));
                               sensor_distance*sin(phi(i))];
            E_z(i,j) = getConductingCylinderFieldUnderPlaneWave(radius(j)*wavelength, ...
                                                              background, ...
                                                              sensor_location*wavelength, ...
                                                              frequency);
        end
    end
    
    RCS  = 2*pi*sensor_distance*(E_z.*conj(E_z));
    % RCS  = RCS./wavelength;
    
    figure; 
    semilogy(rad2deg(phi), RCS(:,1),'b--','linewidth',2); hold('on');
    semilogy(rad2deg(phi), RCS(:,2),'b-','linewidth',2);
    semilogy(rad2deg(phi), RCS(:,3),'b-.','linewidth',2);
    semilogy(rad2deg(phi), RCS(:,4),'r--','linewidth',2);
    semilogy(rad2deg(phi), RCS(:,5),'r-','linewidth',2);
    set(gca,'ytick',[0.2,0.3,0.5,1.0,2,3,5,10,15],'ylim',[0.2 15],'xtick',0:40:160,'plotboxaspectratio',[0.6,1,1]);
    xlabel('\phi (deg)'); 
    ylabel('SW(\sigma_{2-D}/\lambda)');
    legend('0.05\lambda','0.1\lambda','0.2\lambda','0.4\lambda','0.6\lambda');
end


